#
# spec file for package python-libtmux
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-libtmux
Version:        0.27.1
Release:        2.2
Summary:        Python API / wrapper for tmux
License:        MIT
URL:            https://github.com/tmux-python/libtmux/
Source:         https://github.com/tmux-python/libtmux/archive/v%{version}.tar.gz#/libtmux-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module poetry-core}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
# SECTION test
BuildRequires:  %{python_module docutils}
BuildRequires:  %{python_module gp-libs >= 0.0.4}
BuildRequires:  %{python_module myst-parser >= 0.18.1}
BuildRequires:  %{python_module pytest-mock}
BuildRequires:  %{python_module pytest-rerunfailures}
BuildRequires:  %{python_module pytest}
# we do not need pytest-watcher for building on OBS
BuildRequires:  tmux
# /SECTION
BuildArch:      noarch
%python_subpackages

%description
libtmux is a typed python scripting library for tmux. You can use it to command and control tmux servers, sessions, windows, and panes. It is the tool powering tmuxp, a tmux workspace manager.

%prep
%setup -q -n libtmux-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# Move src to a different path to do not use in tests
mv src src.bak
# Tests fail unless src/libtmux/__about__.py exists...
mkdir -p src/libtmux/
cp src.bak/libtmux/__about__.py src/libtmux/

export TMUX_TMPDIR=/tmp
export PYTEST_IGNORE=""
%ifarch x86_64
export PYTEST_IGNORE="-k (not test_session.py::test_select_window or test_test.py::test_function_times_out)"
%endif
%ifarch armv7l
export PYTEST_IGNORE="-k (not test_session.py::test_select_window or test_test.py::test_function_times_out)"
%endif
%ifarch aarch64
export PYTEST_IGNORE="-k (not test_session.py::test_select_window or test_test.py::test_function_times_out)"
%endif
echo "Starting tests with PYTEST_IGNORE set to $PYTEST_IGNORE"
%pytest $PYTEST_IGNORE

rm -rf src/
mv src.bak src

%files %{python_files}
%{python_sitelib}/libtmux/
%{python_sitelib}/libtmux-%{version}*-info
%doc README.md
%license LICENSE

%changelog
* Fri Feb  9 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- ignore some checks again, that seemed fine but are now again
  failing intermittently
* Thu Feb  8 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.27.1:
  * pyproject: Include MIGRATION in sdist by @tony in #517, for
    [#508]
* Thu Feb  8 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.27.0:
  * Improvements
  - QueryList: Generic fixes by @tony in #515
  - This improves the annotations in descendant objects such
    as:
  - Server.sessions
  - Session.windows
  - Window.panes
  - Bolster tests (ported from libvcs): doctests and pytests
* Thu Feb  8 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.26.0:
  * Breaking change
  - get_by_id() (already deprecated) keyword argument renamed
    from id to
  - Server.get_by_id(session_id), Session.get_by_id(window_id),
    and Window.get_by_id(pane_id) (#514)
  * Documentation
  - Various docstring fixes and tweaks (#514)
  * Development
  - Strengthen linting (#514)
  - Add flake8-commas (COM)
  - Add flake8-builtins (A)
  - Add flake8-errmsg (EM)
  * CI
  - Move CodeQL from advanced configuration file to GitHub's
    default
* Mon Nov 27 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 0.25.0:
  * Comparator fixes
  - Fixed __eq__ for windows. by @m1guelperez in #505
  - fix(pane,session,server): Return False if type mismatched by
    @tony in #510
  * Documentation
  - ruff: Enable pydocstyle w/ numpy convention by @tony in #509
* Fri Nov 24 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 0.24.1:
  * packaging: Remove requirements/ folder. Unused. by @tony in
    [#507]
  * pyproject: Add gp-libs to test dependency group
* Mon Nov 20 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 0.24.0:
  * Breaking changes
  - Drop Python 3.7 by @tony in #497
  * Packaging
  - packaging(pytest): Move configuration to pyproject.toml by
    @tony in #499
  - Poetry: 1.5.1 -> 1.6.1 (#497), 1.6.1 -> 1.7.0 (direct to
    trunk)
    See also:
    https://github.com/python-poetry/poetry/blob/1.7.0/CHANGELOG.md
  - Packaging (poetry): Fix development dependencies
    Per Poetry's docs on managing dependencies and poetry check,
    we had it wrong:
    Instead of using extras, we should create these:
    [tool.poetry.group.group-name.dependencies]
    dev-dependency = "1.0.0"
    Which we now do.
  * Development
  - Formatting: black -> ruff format by @tony in #506
  - CI: Update action packages to fix warnings
  - dorny/paths-filter: 2.7.0 -> 2.11.1
  - codecov/codecov-action: 2 -> 3
  * Full Changelog: v0.23.2...v0.24.0
* Mon Sep 11 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 0.23.2:
  _Maintenance only, no bug fixes or new features_
  Final Python 3.7 Release (End of life was June 27th, 2023)
* Wed Sep  6 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 0.23.1:
  _Maintenance only, no bug fixes, or new features_
  * Development
  - Automated typo fixes from [typos-cli]:
    ```console
    typos --format brief --write-changes
    ```
    [typos-cli]: https://github.com/crate-ci/typos
  - ruff's linter for code comments, `ERA` (eradicate), has been
    removed
* Wed Sep  6 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 0.23.0:
  _This maintenance release covers only developer quality of life
  improvements, no bug fixes or new features_
  * Maintenance
  - Stricter code quality rules (via ruff) by @tony in
    https://github.com/tmux-python/libtmux/pull/488
* Wed Sep  6 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 0.22.2:
  _Maintenance only, no bug fixes or features for this release_
  * Build system
  - ci: Remove setuptools requirement for build-system in
    https://github.com/tmux-python/libtmux/pull/495
* Mon May 29 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 0.22.1:
  * Add back black dev dependency until `ruff` replaces black's
    formatting
* Sat May 27 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 0.22.0:
  * Move formatting, import sorting, and linting to ruff.
  * This rust-based checker has dramatically improved performance.
    Linting and formatting can be done almost instantly.
  * This change replaces black, isort, flake8 and flake8 plugins.
* Tue May 16 2023 Johannes Kastl <kastl@b1-systems.de>
- ignore flaky test test_capture_pane (see
  https://github.com/tmux-python/libtmux/issues/484)
- ignore flaky test test_new_window_with_environment[environment0]
  (see https://github.com/tmux-python/libtmux/
  issues/480#issuecomment-1551533987)
* Mon May  8 2023 Daniel Garcia <daniel.garcia@suse.com>
- Depends on poetry-core for building, we don't need the full poetry
  module in this case.
* Fri May  5 2023 Johannes Kastl <kastl@b1-systems.de>
- add sle15_python_module_pythons
* Thu Apr  6 2023 Johannes Kastl <kastl@b1-systems.de>
- ignore yet another test:
  test_new_window_with_environment[environment1]
  (reported at https://github.com/tmux-python/libtmux/issues/478)
* Thu Mar  9 2023 Johannes Kastl <kastl@b1-systems.de>
- new package python-libtmux: Python API / wrapper for tmux
